print("This is the 'NotForSale' mod script.")

include( "IconSupport" );
include( "InstanceManager" );
include( "SupportFunctions" );

local m_StrategicIM = InstanceManager:new( "ResourceInstance", "Root", Controls.StrategicsStack );
local m_LuxuryIM = InstanceManager:new( "ResourceInstance", "Root", Controls.LuxuriesStack );

function ToggleResourceSellableStatus(checkbox, pPlayer, iResource)
    if checkbox:IsChecked() then
        pPlayer:SetResourceNotForSale(iResource);
    else
        pPlayer:SetResourceAvailable(iResource);
    end
end

-- Diplomacy Trade Handlers
Controls.OpenBordersCheckBox:RegisterCheckHandler(function()
    local iPlayer = Game.GetActivePlayer();
    local pPlayer = Players[ iPlayer ];
    pPlayer:SetRefuseOpenBordersTrade(Controls.OpenBordersCheckBox:IsChecked());
end);

Controls.EmbassyCheckBox:RegisterCheckHandler(function()
    local iPlayer = Game.GetActivePlayer();
    local pPlayer = Players[ iPlayer ];
    pPlayer:SetRefuseEmbassyTrade(Controls.EmbassyCheckBox:IsChecked());
end);

Controls.DefensivePactCheckBox:RegisterCheckHandler(function()
    local iPlayer = Game.GetActivePlayer();
    local pPlayer = Players[ iPlayer ];
    pPlayer:SetRefuseDefensivePactTrade(Controls.DefensivePactCheckBox:IsChecked());
end);

Controls.BrokeredWarCheckBox:RegisterCheckHandler(function()
    local iPlayer = Game.GetActivePlayer();
    local pPlayer = Players[ iPlayer ];
    pPlayer:SetRefuseBrokeredWarTrade(Controls.BrokeredWarCheckBox:IsChecked());
end);

Controls.BrokeredPeaceCheckBox:RegisterCheckHandler(function()
    local iPlayer = Game.GetActivePlayer();
    local pPlayer = Players[ iPlayer ];
    pPlayer:SetRefuseBrokeredPeaceTrade(Controls.BrokeredPeaceCheckBox:IsChecked());
end);

Controls.ResearchAgreementCheckBox:RegisterCheckHandler(function()
    local iPlayer = Game.GetActivePlayer();
    local pPlayer = Players[ iPlayer ];
    pPlayer:SetRefuseResearchAgreementTrade(Controls.ResearchAgreementCheckBox:IsChecked());
end);

function IsUntradeableResource(eResource)
    return eResource.Type == 'RESOURCE_PAPER';
end

function UpdateScreen()
    m_SortTable = {};
    local iPlayer = Game.GetActivePlayer();
    local pPlayer = Players[ iPlayer ];

    m_StrategicIM:ResetInstances();
    m_LuxuryIM:ResetInstances();

    -- Set diplomacy checkboxes
    Controls.OpenBordersCheckBox:SetCheck(pPlayer:IsRefuseOpenBordersTrade());
    Controls.EmbassyCheckBox:SetCheck(pPlayer:IsRefuseEmbassyTrade());
    Controls.DefensivePactCheckBox:SetCheck(pPlayer:IsRefuseDefensivePactTrade());
    Controls.BrokeredWarCheckBox:SetCheck(pPlayer:IsRefuseBrokeredWarTrade());
    Controls.BrokeredPeaceCheckBox:SetCheck(pPlayer:IsRefuseBrokeredPeaceTrade());
    Controls.ResearchAgreementCheckBox:SetCheck(pPlayer:IsRefuseResearchAgreementTrade());

    local bShowUnownedResources = Controls.ShowUnownedCheckBox:IsChecked();
    for resource in GameInfo.Resources() do
        local instance;
        local iResource = resource.ID;
        local strTradeInfo = "";
        local iExports = 0;
        local iAvailable = 0;

        local iResourceTotal = pPlayer:GetNumResourceTotal( iResource, true );

        if (bShowUnownedResources or iResourceTotal > 0) and not IsUntradeableResource(resource) then
            iAvailable = pPlayer:GetNumResourceAvailable( iResource, true );

            if( Game.GetResourceUsageType( iResource ) == ResourceUsageTypes.RESOURCEUSAGE_STRATEGIC ) then
                instance = m_StrategicIM:GetInstance();
            elseif( Game.GetResourceUsageType( iResource ) == ResourceUsageTypes.RESOURCEUSAGE_LUXURY ) then
                instance = m_LuxuryIM:GetInstance();
            end

            if instance ~= nil then
                instance.ResourceCheckBox:SetCheck(pPlayer:IsResourceNotForSale(iResource));
                instance.ResourceCheckBox:RegisterCheckHandler( function() ToggleResourceSellableStatus(instance.ResourceCheckBox, pPlayer, iResource) end );
                local sortEntry = {};
                m_SortTable[ tostring( instance.Root ) ] = sortEntry;
                sortEntry.name = Locale.ConvertTextKey( resource.Description );
                instance.ResourceQty:SetText( iAvailable );
                TruncateString( instance.ResourceName, 140, resource.IconString .. " " .. sortEntry.name );

                -- instance.TradeInfo:SetText( strTradeInfo );
                instance.ResourceStack:CalculateSize();
                instance.ResourceStack:ReprocessAnchoring();
            end
        end
    end

    Controls.StrategicsStack:CalculateSize();
    Controls.StrategicsStack:ReprocessAnchoring();
    Controls.StrategicsScrollPanel:CalculateInternalSize();
    Controls.StrategicsScrollPanel:ReprocessAnchoring();

    Controls.LuxuriesStack:CalculateSize();
    Controls.LuxuriesStack:ReprocessAnchoring();
    Controls.LuxuriesScrollPanel:CalculateInternalSize();
    Controls.LuxuriesScrollPanel:ReprocessAnchoring();
end
Controls.ShowUnownedCheckBox:RegisterCheckHandler(UpdateScreen);
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
function ShowHideHandler( bIsHide, bInitState )

    -- Set player icon at top of screen
    CivIconHookup( 0, 64, Controls.Icon, Controls.CivIconBG, Controls.CivIconShadow, false, true );
    UpdateScreen();
end
ContextPtr:SetShowHideHandler( ShowHideHandler );

ContextPtr:SetHide(true);


function InputHandler( uiMsg, wParam, lParam )
    if uiMsg == KeyEvents.KeyDown then
        if wParam == Keys.VK_ESCAPE or wParam == Keys.VK_RETURN then
            OnClose();
            return true;
        end
    end
end
ContextPtr:SetInputHandler( InputHandler );

function OnClose ()
  ContextPtr:SetHide(true)
end
Controls.CloseButton:RegisterCallback(Mouse.eLClick, OnClose)

function Open()
    ContextPtr:SetHide(false)
end

----------------------------------------------------------------
-- 'Active' (local human) player has changed
----------------------------------------------------------------
-- Boilerplate
function OnDiploCornerPopup()
    Open();
  -- ContextPtr:SetHide(false)
end

function OnAdditionalInformationDropdownGatherEntries(additionalEntries)
  table.insert(additionalEntries, {text=Locale.ConvertTextKey("TXT_KEY_NFS_NOT_FOR_SALE"), call=OnDiploCornerPopup, art="DC45_NotForSale.dds"})
end

LuaEvents.AdditionalInformationDropdownGatherEntries.Add(OnAdditionalInformationDropdownGatherEntries)
LuaEvents.RequestRefreshAdditionalInformationDropdownEntries()

Events.GameplaySetActivePlayer.Add(OnClose)

print("Loaded NotForSale.lua")